Clazz.declarePackage("JM");
Clazz.declareInterface(JM, "Structure");
;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
